@@ -21,12 +21,10 @@
 #include "config.h"
 #endif
 
-#include <malloc.h>
-#include <math.h>
+#include <stdlib.h>
 
 #include <qwidget.h>
 #include <qpainter.h>
-#include <qevent.h>
 
 #include "graph.moc"
 
@@ -36,16 +34,19 @@ Graph::Graph(QWidget *parent, const char *name)
   : QWidget(parent, name),
     dataSamples(0), dataSize(0), dataPtr(0), 
     dataMax(0), dataMaxSize(0), dataMaxPtr(0), 
-    colorA(Qt::green), colorB(Qt::red)
+    autoMaxValue(true),
+    colorA(Qt::green), colorB(Qt::red), colorBg(Qt::black)
 {
   setup();
 }
 
-Graph::Graph(const QColor cA, const QColor cB, QWidget *parent, const char *name)
+Graph::Graph(const QColor cA, const QColor cB, const QColor cBg,
+	     QWidget *parent, const char *name)
   : QWidget(parent, name),
     dataSamples(0), dataSize(0), dataPtr(0), 
     dataMax(0), dataMaxSize(0), dataMaxPtr(0), 
-    colorA(cA), colorB(cB)
+    autoMaxValue(true),
+    colorA(cA), colorB(cB), colorBg(cBg)
 {
   setup();
 }
@@ -53,7 +54,7 @@ Graph::Graph(const QColor cA, const QColor cB, QWidget *parent, const char *name
 inline void Graph::setup()
 {
   setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-  setPaletteBackgroundColor(Qt::black);
+  setPaletteBackgroundColor(colorBg);
 }
 
 Graph::~Graph()
@@ -64,6 +65,16 @@ Graph::~Graph()
   }
 }
 
+void Graph::calcMaxValue()
+{
+  // calculate the maxValue of the display
+  maxValue = 0;
+  for(unsigned int i=0; i<dataMaxPtr; ++i) {
+    if (dataMax[i] > maxValue)
+      maxValue = dataMax[i];
+  }
+}
+
 void Graph::addValues(unsigned int a, unsigned int b)
 {
   if(!dataSize) return;
@@ -90,12 +101,8 @@ void Graph::addValues(unsigned int a, unsigned int b)
     ++dataMaxPtr;
   }
 
-  // set the maxValue of the display
-  maxValue = 0;
-  for(unsigned int i=0; i<dataMaxPtr; ++i) {
-    if (dataMax[i] > maxValue)
-      maxValue = dataMax[i];
-  }
+  if (autoMaxValue) calcMaxValue();
+  
   repaint();
 }
 
@@ -125,14 +132,32 @@ void Graph::paintEvent(QPaintEvent *)
   p.setPen(colorA);
   for(unsigned int i=0; i<dataPtr; ++i) {
     int v = int(dataSamples[i].a*mh);
-    if(v)
+    if(v) {
+      if (v>h) v=h;
       p.drawLine(i, h-1, i, h-v);
+    }
   }
   p.setPen(colorB);
   for(unsigned int i=0; i<dataPtr; ++i) {
     int v = int(dataSamples[i].b*mh);
-    if (v) 
+    if (v) {
+      if (v>h) v=h;      
       p.drawLine(i, h-1, i, h-v);
+    }
   }
   p.flush();
 }
+
+void Graph::setMaxValue(unsigned int m) 
+{ 
+  maxValue = m;
+  autoMaxValue = false;
+  update();
+}
+
+void Graph::unsetMaxValue()
+{ 
+  autoMaxValue = true;
+  calcMaxValue();
+  update();
+}
