@@ -29,15 +29,23 @@ class Graph : public QWidget
 
  public:
   Graph(QWidget *parent = 0, const char * name = 0);
-  Graph(const QColor cA, const QColor cB, QWidget *parent = 0, const char * name = 0);
+  Graph(const QColor cA, const QColor cB, const QColor cBg, 
+	QWidget *parent = 0, const char * name = 0);
   ~Graph();
 
   virtual QSize sizeHint () const;
 
   void addValues(unsigned int a, unsigned int b);
-  void setColors(const QColor &a, const QColor &b);
+  void setColorA(const QColor &);
+  void setColorB(const QColor &);
+  void setColorBg(const QColor &);
   QColor getColorA() const { return colorA; };
   QColor getColorB() const { return colorB; };
+  QColor getColorBg() const { return colorBg; };
+  void setMaxValue(unsigned int m);
+  void unsetMaxValue();
+  unsigned int getMaxValue() { return maxValue; };
+  bool autoMax() { return autoMaxValue; };
 
  protected:
   virtual void resizeEvent(QResizeEvent *);
@@ -45,6 +53,7 @@ class Graph : public QWidget
 
  private:
   void setup();
+  void calcMaxValue();
 
   // dateSamples
   struct Samples{
@@ -59,9 +68,10 @@ class Graph : public QWidget
   size_t dataMaxSize;
   size_t dataMaxPtr;
   unsigned int maxValue;
+  bool autoMaxValue;
 
   // colors
-  QColor colorA, colorB;
+  QColor colorA, colorB, colorBg;
 
 };
 
@@ -70,11 +80,23 @@ inline QSize Graph::sizeHint () const
   return QSize(22, 22);
 }
 
-inline void Graph::setColors(const QColor &a, const QColor &b) 
+inline void Graph::setColorA(const QColor &a) 
 { 
   colorA = a; 
+  update(); 
+}
+
+inline void Graph::setColorB(const QColor &b) 
+{ 
   colorB = b; 
   update(); 
 }
 
+inline void Graph::setColorBg(const QColor &bg) 
+{ 
+  colorBg = bg;
+  setPaletteBackgroundColor(colorBg);
+  update(); 
+}
+
 #endif
