@@ -27,9 +27,10 @@
 #include <qpushbutton.h>
 #include <qlabel.h>
 
+#include "kpanelapplet.h"
+
 #include "statusbutton.h"
 #include "modem.h"
-#include "kpanelapplet.h"
 
 
 class MapWidget;
@@ -100,6 +101,9 @@ class KModemLightsApplet : public KPanelApplet
   QString connectCommand;
   QString disconnectCommand;
   int updateFrequency;
+  bool showRequesters;
+  unsigned int graphMaxValue;
+
   Modem modem;
 
   // memory for timerEvent
