@@ -22,14 +22,11 @@
 
 #include <qspinbox.h>
 #include <qlineedit.h>
-#include <qfont.h>
+#include <qcheckbox.h>
+
 #include <kdialogbase.h>
 #include <kcolorbutton.h>
 
-class QGrid;
-class QPushButton;
-class QLabel;
-class KColorButton;
 class KModemLightsApplet;
 
 class KModemLightsDlg : public KDialogBase {
@@ -37,16 +34,21 @@ class KModemLightsDlg : public KDialogBase {
   
  public:
 
-  KModemLightsDlg::KModemLightsDlg(QWidget *parent, const char *name,
-				   KModemLightsApplet *ap);
+  KModemLightsDlg::KModemLightsDlg(KModemLightsApplet *ap, QWidget *parent = 0, 
+				   const char *name = 0);
 
   // get Device
-  int updateFrequency() const { return frequencyWidget->value(); };
   QString deviceName() const { return deviceWidget->text(); };
   QString lockFile() const { return lockFileWidget->text(); };
   QString connectCommand() const { return connectWidget->text(); };
   QString disconnectCommand() const { return disconnectWidget->text(); };
 
+  // get general
+  int updateFrequency() const { return frequencyWidget->value(); };
+  bool showRequesters() const { return showRequestersWidget->isChecked(); };
+  bool graphAutoMax() const { return autoMaxWidget->isChecked(); };
+  unsigned int graphMaxValue() const { return maxValueWidget->text().toUInt(); };
+
   // get Colors
   QColor rxOnColor() const { return rxOn->color(); };
   QColor rxOffColor() const { return rxOff->color(); };
@@ -56,11 +58,14 @@ class KModemLightsDlg : public KDialogBase {
   QColor txGraphColor() const { return txGraph->color(); };
   QColor statusAwaitColor() const { return statusAwait->color(); };
   QColor statusOnColor() const { return statusOn->color(); };
+  QColor graphBgColor() const { return graphBg->color(); };
 
  private:
 
+  QWidget *generateGeneral();
   QWidget *generateDevice();
   QWidget *generateColor();
+  QLabel *newCaption(const QString &s, QWidget *w);
 
   KModemLightsApplet *applet;
 
@@ -70,13 +75,15 @@ class KModemLightsDlg : public KDialogBase {
   QLineEdit *lockFileWidget;
   QLineEdit *connectWidget;
   QLineEdit *disconnectWidget;
+  QCheckBox *showRequestersWidget;
+  QCheckBox *autoMaxWidget;
+  QLineEdit *maxValueWidget;
 
   // Colors
   KColorButton *rxOn, *rxOff, *rxGraph;
   KColorButton *txOn, *txOff, *txGraph;
   KColorButton *statusAwait, *statusOn;
-
-  QLabel *fontShowWidget;
+  KColorButton *graphBg;
 
  private slots:
 
