@@ -21,7 +21,7 @@
 #include "config.h"
 #endif
 
-#include <qlabel.h>
+#include <qwidget.h>
 #include <qpainter.h>
 
 #include "light.moc"
@@ -34,9 +34,9 @@ QPixmap Light::lightPixmapL, Light::lightMaskL;
 
 Light::Light(const QColor &cOn, const QColor &cOff, 
 	     QWidget *parent, const char *name)
-  : QLabel(parent, name),
+  : QWidget(parent, name),
     lightStatus(false), bigLights(false),
-    colorOn(cOn), colorOff(cOff)
+    colorOn(cOn), colorOff(cOff), offx(0), offy(0)
     
 {
   if(lightPixmapS.isNull()) {
@@ -48,11 +48,32 @@ Light::Light(const QColor &cOn, const QColor &cOff,
 
   generateIcon(on, colorOn);
   generateIcon(off, colorOff);
-
+  
   setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-  setAlignment(Qt::AlignHCenter|Qt::AlignVCenter);
+}
 
-  setPixmap(off);
+void Light::paintEvent(QPaintEvent *)
+{
+  QPainter paint(this);
+  paint.drawPixmap(offx, offy, lightStatus ? on : off);
+}
+
+void Light::resizeEvent(QResizeEvent *e)
+{
+  offx = (width() - on.width())/2;
+  offy = (height() - on.height())/2;
+
+  QWidget::resizeEvent(e);
+}
+
+QSize Light::sizeHint() const
+{
+  return on.size();
+}
+
+QSize Light::minimumSizeHint() const
+{
+  return on.size();
 }
 
 void Light::setStatus(bool s)
@@ -60,9 +81,8 @@ void Light::setStatus(bool s)
   if (s == lightStatus)
     return;
 
-  setPixmap( s ? on : off);
   lightStatus = s;
-  update();
+  repaint();
 }
 
 void Light::setColors(const QColor &cOn, const QColor &cOff)
@@ -70,18 +90,14 @@ void Light::setColors(const QColor &cOn, const QColor &cOff)
   if (colorOn != cOn) {
     colorOn = cOn;
     generateIcon(on, colorOn);
-    if (lightStatus) {
-      setPixmap(on);
+    if (lightStatus)
       update();
-    }
   }
   if (colorOff != cOff) {
     colorOff = cOff;
     generateIcon(off, colorOff);
-    if (!lightStatus) {
-      setPixmap(off);
+    if (!lightStatus)
       update();
-    }
   }
 }
 
@@ -93,7 +109,6 @@ void Light::setBig(bool b)
   bigLights = b;
   generateIcon(on, colorOn);
   generateIcon(off, colorOff);
-  setPixmap(lightStatus ? on : off);
   update();
 }
 
